/* option.h --
   Copyright (C) 1998 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and'or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
   USA */

/* Written by Changwoo Ryu <cwryu@adam.kaist.ac.kr>. */

#ifndef __FREECELLGAME__OPTION_H
#define __FREECELLGAME__OPTION_H

#include <gconf/gconf-client.h>

extern gboolean option_inform_invalid_move;
extern gboolean option_move_one_by_one;

void option_init (void);
void option_write (void);

gint
freecell_gconf_get_int (GConfClient *client, gchar *key, gint default_int);
gboolean
freecell_gconf_get_bool (GConfClient *client, gchar *key, gint default_bool);

#endif /* __FREECELLGAME__OPTION_H */
